@@ -44,12 +44,14 @@ BANK_STATEMENT_FILE_INPUT_CSS_SELECTOR = "input[title='Statement file']"
 BANK_STATEMENT_FILE_SPAN_CSS_SELECTOR = "span[title='Statement file']"
 BACK_CSS_SELECTOR = "div[title='Back (F3)']"
 LOG_OFF_CSS_SELECTOR = "div[title='Log Off (Shift+F3)']"
-ALWAYS_EXCEL_CSS_SELECTOR = "span[aria-label='Always Use Selected Format']"
+# ALWAYS_EXCEL_CSS_SELECTOR = "span[aria-label='Always Use Selected Format']"
+ALWAYS_EXCEL_CSS_SELECTOR = ".urPWContentTableCellWorkaround .lsCheckBox--unchecked"
 # FIREFOX_BINARY_DEFAULT_LOCATION = r'C:\Program Files\Mozilla Firefox\firefox.exe'
 EXCEL_CONTINUE_CSS_SELECTOR = "div[title='Continue (Enter)']"
 LOGIN_CONTINUE_BUTTON_CSS_SELECTOR = "span[id$='CONTINUE_BUTTON-caption']"
 Y01F_FILE_NAME_INPUT_CSS_SELECTOR = "input[title='File for Report Writer output']"
 Y01F_DOWNLOAD_CONTINUE_BUTTON_CSS_SELECTOR = "div[lsdata*=\"'Continue'\"]"
-CANCEL_BY_USER_CSS_SELECTOR = ".lsMessageBar__text "
+CANCEL_BY_USER_CSS_SELECTOR = ".lsMessageBar__text"
 SE16_LAYOUT_TH_CSS_SELECTOR = ".urPWContentTableCellWorkaround div.lsContainer--verticalsizing-fill table[id$='-mrss-hdr-none-content'] th:first-child"
 SE16_LAYOUT_SPAN_CSS_SELECTOR = ".urPWContentTableCellWorkaround table[id$='-mrss-cont-none-content'] tbody tr td:first-child span span"
+# SSL_CERTIFICATE_PATH = '/usr/local/share/ca-certificates/ca-bundle.crt'
