@@ -10,7 +10,7 @@ from typing import Tuple
 import functools
 import pyperclip
 import tempfile
-from threading import Thread
+from threading import Thread, Event
 from selenium import webdriver
 from selenium.common.exceptions import NoSuchElementException, StaleElementReferenceException, ElementNotInteractableException, \
     MoveTargetOutOfBoundsException, InvalidSessionIdException, TimeoutException
@@ -50,7 +50,7 @@ class WebSapCommonFunctions:
         """
         self.sap_system = 'poe'
         self.save_folder_path = ''
-        self.stop_screenshot_thread = True
+        self.stop_screenshot_thread = Event()
         self.thr = None
         self.time_interval = 15
 
@@ -189,7 +189,6 @@ class WebSapCommonFunctions:
         if auto_get_screenshot:
             self.apply_decorator_to_methods()
             self.time_interval = time_interval
-            self.stop_screenshot_thread = False
             self.thr = Thread(target=self.auto_get_browser_screenshots,
                               args=[save_folder_path, time_interval, browser_screenshot_tag, remote_save, username, password, server_name, share_name, remote_folder_path],
                               daemon=True)
@@ -197,15 +196,87 @@ class WebSapCommonFunctions:
 
         return self.browser, self.wait
 
+    def keep_sap_session_alive(self):
+        """Prevent SAP session timeout by periodic simulated activity."""
+        js_script = """
+        (() => {
+          console.log("🚀 Starting SAP WebGUI keepalive task...");
+
+          async function sendKeepalive() {
+            try {
+              const origin = window.location.origin;
+              const tokenRegex = /\\/sap\\(.*?\\)\\//;
+              let tokenMatch = window.location.pathname.match(tokenRegex);
+
+              if (!tokenMatch) {
+                console.log("⚙️ 当前 URL 无 token，尝试从入口页重新抓取...");
+                const entryUrl = `${origin}/sap/bc/gui/sap/its/webgui?sap-client=011&sap-language=EN`;
+                const entryRes = await fetch(entryUrl, {
+                  method: "GET",
+                  credentials: "include",
+                  headers: { "Accept": "text/html" },
+                });
+                const entryHtml = await entryRes.text();
+                tokenMatch = entryHtml.match(tokenRegex);
+              }
+
+              if (!tokenMatch) {
+                console.error("❌ 未找到 /sap(cz1...)/ token，请确认已登录 SAP WebGUI。");
+                return;
+              }
+
+              const tokenPath = tokenMatch[0];
+              const batchUrl = `${origin}${tokenPath}bc/gui/sap/its/webgui/batch/json?~RG_WEBGUI=X&sap-statistics=true`;
+
+              console.log(`🔁 [${new Date().toLocaleTimeString()}] Sending keepalive → ${batchUrl}`);
+
+              const res = await fetch(batchUrl, {
+                method: "POST",
+                credentials: "include",
+                headers: {
+                  "Accept": "application/json, text/javascript, */*; q=0.01",
+                  "Content-Type": "application/json;charset=UTF-8",
+                },
+                body: JSON.stringify([{ get: "state/ur" }]),
+              });
+
+              const text = await res.text();
+              if (res.ok) {
+                if (text.includes("X-Status: OK") || text.includes("<update")) {
+                  console.log(`✅ [${new Date().toLocaleTimeString()}] Session refreshed successfully.`);
+                } else if (text.includes("login") || text.includes("SAP NetWeaver")) {
+                  console.warn(`⚠️ [${new Date().toLocaleTimeString()}] Session expired, login page returned.`);
+                } else {
+                  console.log(`📄 [${new Date().toLocaleTimeString()}] Response partial:`, text.slice(0, 200));
+                }
+              } else {
+                console.warn(`⚠️ [${new Date().toLocaleTimeString()}] Keepalive failed: ${res.status} ${res.statusText}`);
+              }
+            } catch (err) {
+              console.error(`❌ [${new Date().toLocaleTimeString()}] Keepalive error:`, err);
+            }
+          }
+
+          // 立即执行一次，然后每 60 秒执行一次
+          sendKeepalive();
+          const KEEPALIVE_INTERVAL = 60 * 1000; // 60 秒
+          window.__sap_keepalive_timer__ = setInterval(sendKeepalive, KEEPALIVE_INTERVAL);
+
+          console.log(`⏱️ SAP keepalive timer started, interval = ${KEEPALIVE_INTERVAL / 1000}s`);
+        })();
+        """
+
+        self.browser.execute_script(js_script)
+
     def stop_auto_get_browser_screenshots(self):
         """ This function is used to stop auto get browser screenshots
 
         """
-        if not self.stop_screenshot_thread:
-            sleep(self.time_interval + 1)
-            self.stop_screenshot_thread = True
-            if self.thr is not None:
-                self.thr.join()
+        # if not self.stop_screenshot_thread.is_set():
+        sleep(self.time_interval + 1)
+        self.stop_screenshot_thread.set()
+        if self.thr is not None:
+            self.thr.join(timeout=5)
 
     def auto_get_browser_screenshots(self, save_folder_path, time_interval=15, browser_screenshot_tag='', remote_save=False, username='', password='', server_name='',
                                      share_name='', remote_folder_path=''):
@@ -229,9 +300,13 @@ class WebSapCommonFunctions:
         for file_name in os.listdir(screenshot_folder_path):
             os.remove(screenshot_folder_path + os.sep + file_name)
 
-        smb_client = SmbFunctionsManager(username, password, server_name, share_name)
+        try:
+            smb_client = SmbFunctionsManager(username, password, server_name, share_name)
+        except:
+            smb_client = None
+            # print('[SMB CONNECTION ERROR]:', traceback.format_exc())
 
-        while not self.stop_screenshot_thread:
+        while not self.stop_screenshot_thread.is_set():
             if time_interval < 5:
                 sleep(5)
             else:
@@ -247,7 +322,7 @@ class WebSapCommonFunctions:
             try:
                 self.browser.save_screenshot(screenshot_file_path)
                 sleep(1)
-                if remote_save:
+                if remote_save and smb_client is not None:
                     remote_screenshot_folder_path = remote_folder_path + os.sep + 'Screenshots'
                     # is_folder_exist = smb_check_folder_exist(username, password, server_name, share_name, remote_screenshot_folder_path)
                     is_folder_exist = smb_client.smb_check_folder_exist(remote_screenshot_folder_path)
@@ -451,6 +526,7 @@ class WebSapCommonFunctions:
             # self.wait.until(EC.invisibility_of_element_located((By.ID, INFO_BOX_ID)))
             # sleep(2)
             # self.wait_invisibility_of_loading_window()
+            # self.keep_sap_session_alive()
             return True
         else:
             return False
@@ -663,15 +739,18 @@ class WebSapCommonFunctions:
         sleep(1)
         action_chains.reset_actions()
 
-    def activate_context_click(self, css_selector: str, by: By = By.CSS_SELECTOR):
+    def activate_context_click(self, css_selector: str, target_element: WebElement = None, by: By = By.CSS_SELECTOR):
         """This function is used to execute context click
 
         Args:
             css_selector(str): This is the css selector which will receive context click
+            target_element(WebElement): This is the target element
             by(By): This is the By method to find element
         """
-        self.wait_element_presence_by_css_selector(css_selector, by=by)
-        target_element = self.browser.find_element(by, css_selector)
+        if not target_element:
+            self.wait_element_presence_by_css_selector(css_selector, by=by)
+            target_element = self.browser.find_element(by, css_selector)
+
         action_chains = ActionChains(self.browser)
         action_chains.context_click(target_element).perform()
         sleep(1)
@@ -802,13 +881,13 @@ class WebSapCommonFunctions:
             actions.perform()
             actions.reset_actions()
             sleep(2)
-            try:
-                self.browser.find_element(By.CSS_SELECTOR, EXCEL_CONTINUE_CSS_SELECTOR)
-            except NoSuchElementException:
-                pass
-            else:
-                self.click_or_input_by_css_selector(EXCEL_CONTINUE_CSS_SELECTOR, 'click')
-                sleep(2)
+            # try:
+            #     self.browser.find_element(By.CSS_SELECTOR, EXCEL_CONTINUE_CSS_SELECTOR)
+            # except NoSuchElementException:
+            #     pass
+            # else:
+            #     self.click_or_input_by_css_selector(EXCEL_CONTINUE_CSS_SELECTOR, 'click')
+            #     sleep(2)
             self.wait_invisibility_of_loading_window()
 
         is_cancelled = False
@@ -1757,9 +1836,9 @@ class WebSapCommonFunctions:
         """This function is used to quit browser
 
         """
-        if not self.stop_screenshot_thread:
-            self.stop_screenshot_thread = True
+        if not self.stop_screenshot_thread.is_set():
+            self.stop_screenshot_thread.set()
             if self.thr is not None:
-                self.thr.join()
+                self.thr.join(timeout=5)
 
         self.browser.quit()
