@@ -1,12 +1,7 @@
 import io
-import uuid
+import os
 import smbclient
-from smbprotocol.connection import Connection
-from smbprotocol.session import Session
-from smbprotocol.tree import TreeConnect
-from smbprotocol.open import Open
-from smbprotocol.file_info import FileInformationClass
-from smbprotocol.exceptions import SMBResponseException, NtStatus
+import pandas as pd
 
 
 class SmbFunctionsManager:
@@ -19,10 +14,11 @@ class SmbFunctionsManager:
         self.port = port
         self.encrypt = encrypt
         self.connection_cache = {}
-
-    def __enter__(self):
         self.initialize_smb_connection()
-        return self
+
+    # def __enter__(self):
+    #     self.initialize_smb_connection()
+    #     return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close_smb_connection()
@@ -176,63 +172,22 @@ class SmbFunctionsManager:
             share_name(str): This is the  share_name of public folder, e.g. GS
         """
         server_name, share_name = self.prepare_server_name_share_name(server_name, share_name)
+        full_remote_folder_path = f"//{server_name}/{share_name}/{remote_folder_path}".rstrip("/")
 
         traverse_result_list = []
-        client_guid = uuid.uuid4()
-        connection = Connection(guid=client_guid, server_name=server_name, port=self.port)
-        connection.connect()
 
-        session = Session(connection, self.username, self.password)
-        session.connect()
-
-        tree = TreeConnect(session, f"\\\\{server_name}\\{share_name}")
-        tree.connect()
-
-        folder_open = Open(tree, remote_folder_path)
-        folder_open.create(impersonation_level=0,
-                           desired_access=0x00000001,  # read only
-                           file_attributes=0,
-                           share_access=0x00000001,  # allow other process
-                           create_disposition=1,  # OPEN_EXISTING
-                           create_options=0
-                           )
-        try:
-            pattern = "*"  # match all
-            file_information_class = FileInformationClass.FILE_DIRECTORY_INFORMATION
-            # file_info = folder_open.query_directory(pattern, file_information_class)
-
-            all_file_info = []
-            while True:
-                try:
-                    batch = folder_open.query_directory(pattern, file_information_class)
-                    if not batch:
-                        break
-                    all_file_info.extend(batch)
-                except SMBResponseException as e:
-                    if e.status == NtStatus.STATUS_NO_MORE_FILES:
-                        break
-                    raise
-
-            for item in all_file_info:
-                item_name = item.fields.get('file_name').value.decode('utf-16')
-                if item_name not in ['.', '..']:
-                    creation_time = item.fields.get('creation_time').value
-                    last_access_time = item.fields.get('last_access_time').value
-                    last_write_time = item.fields.get('last_write_time').value
-                    change_time = item.fields.get('change_time').value
-
-                    if item.fields.get('file_attributes').value & 0x10:  # check whether item is folder
-                        traverse_result_list.append({'name': item_name,
-                                                     'is_folder': True, 'is_file': False, 'creation_time': creation_time, 'last_access_time': last_access_time,
-                                                     'last_write_time': last_write_time, 'change_time': change_time})
-                    else:
-                        traverse_result_list.append({'name': item_name,
-                                                     'is_folder': False, 'is_file': True, 'creation_time': creation_time, 'last_access_time': last_access_time,
-                                                     'last_write_time': last_write_time, 'change_time': change_time})
-        finally:
-            connection.disconnect()
-            session.disconnect()
-            tree.disconnect()
+        for entry in smbclient.scandir(full_remote_folder_path, connection_cache=self.connection_cache):
+            if entry.name not in [".", ".."]:
+                stat_info = entry.stat()
+                traverse_result_list.append({
+                    "name": entry.name,
+                    "is_folder": entry.is_dir(),
+                    "is_file": entry.is_file(),
+                    "creation_time": stat_info.st_ctime,
+                    "last_access_time": stat_info.st_atime,
+                    "last_write_time": stat_info.st_mtime,
+                    "change_time": stat_info.st_mtime,
+                })
 
         return traverse_result_list
 
